@@ -3,9 +3,11 @@
 #   @brief Example Script simple session
 #   @ingroup python_bindings_examples
 
-from gnucash import \
-     Session, GnuCashBackendException, \
+from gnucash import (
+     Session, GnuCashBackendException,
+     SessionOpenMode,
      ERR_BACKEND_LOCKED, ERR_FILEIO_FILE_NOT_FOUND
+)
 
 FILE_1 = "/tmp/not_there.xac"
 FILE_2 = "/tmp/example_file.xac"
@@ -19,18 +21,13 @@ except GnuCashBackendException as backend_exception:
 
 
 # create a new file, this requires a file type specification
-session = Session("xml://%s" % FILE_2, is_new=True)
-session.save()
-session.end()
-session.destroy()
+with Session("xml://%s" % FILE_2, SessionOpenMode.SESSION_NEW_STORE) as session:
+    book = session.book
+    root = book.get_root_account()
 
 # open the new file, try to open it a second time, detect the lock
-session = Session(FILE_2)
-try:
-    session_2 = Session(FILE_2)
-except GnuCashBackendException as backend_exception:
-    assert( ERR_BACKEND_LOCKED in backend_exception.errors )
-session.end()
-session.destroy()
-
-    
+with Session(FILE_2) as session:
+    try:
+        session_2 = Session(FILE_2)
+    except GnuCashBackendException as backend_exception:
+        assert( ERR_BACKEND_LOCKED in backend_exception.errors )
