@@ -478,7 +478,10 @@ search_update_query (GNCSearchWindow *sw)
         if (pdata)
         {
             q2 = create_query_fragment(sw->search_for, GNC_SEARCH_PARAM (data->param), pdata);
-            q = qof_query_merge (q, q2, op);
+            new_q = qof_query_merge (q, q2, op);
+            qof_query_destroy (q);
+            qof_query_destroy (q2);
+            q = new_q;
         }
     }
 
