@@ -62,6 +62,7 @@ static QofLogModule log_module = GNC_MOD_GUI;
 
 void gnc_prices_dialog_destroy_cb (GtkWidget *object, gpointer data);
 void gnc_prices_dialog_close_cb (GtkDialog *dialog, gpointer data);
+void gnc_prices_dialog_help_cb (GtkDialog *dialog, gpointer data);
 void gnc_prices_dialog_edit_clicked (GtkWidget *widget, gpointer data);
 void gnc_prices_dialog_remove_clicked (GtkWidget *widget, gpointer data);
 void gnc_prices_dialog_remove_old_clicked (GtkWidget *widget, gpointer data);
@@ -134,6 +135,15 @@ gnc_prices_dialog_close_cb (GtkDialog *dialog, gpointer data)
 }
 
 
+void
+gnc_prices_dialog_help_cb (GtkDialog *dialog, gpointer data)
+{
+    PricesDialog *pdb_dialog = data;
+
+    gnc_gnome_help (GTK_WINDOW (pdb_dialog->window), HF_HELP, HL_PRICE_DB);
+}
+
+
 void
 gnc_prices_dialog_edit_clicked (GtkWidget *widget, gpointer data)
 {
