@@ -135,7 +135,7 @@ typedef struct GncPluginPageReportPrivate
 G_DEFINE_TYPE_WITH_PRIVATE(GncPluginPageReport, gnc_plugin_page_report, GNC_TYPE_PLUGIN_PAGE)
 
 #define GNC_PLUGIN_PAGE_REPORT_GET_PRIVATE(o)  \
-   ((GncPluginPageReportPrivate*)g_type_instance_get_private((GTypeInstance*)o, GNC_TYPE_PLUGIN_PAGE_REPORT))
+   ((GncPluginPageReportPrivate*)gnc_plugin_page_report_get_instance_private((GncPluginPageReport*)o))
 
 static void gnc_plugin_page_report_class_init( GncPluginPageReportClass *klass );
 static void gnc_plugin_page_report_init( GncPluginPageReport *plugin_page );
@@ -1812,7 +1812,7 @@ static gchar *report_create_jobname(GncPluginPageReportPrivate *priv)
         char *format_code = gnc_prefs_get_string (GNC_PREFS_GROUP_REPORT_PDFEXPORT,
                                                   GNC_PREF_FILENAME_DATE_FMT);
         const gchar *date_format_string;
-        if (*format_code == '\0')
+        if (!(format_code && *format_code))
         {
             g_free(format_code);
             format_code = g_strdup("locale");
@@ -1872,8 +1872,17 @@ static gchar *report_create_jobname(GncPluginPageReportPrivate *priv)
         // Look up the sprintf format of the output name from the preferences database
         char* format = gnc_prefs_get_string(GNC_PREFS_GROUP_REPORT_PDFEXPORT, GNC_PREF_FILENAME_FMT);
 
-        job_name = g_strdup_printf(format, report_name, report_number, job_date);
-
+        if (format && *format)
+        {
+            job_name = g_strdup_printf(format, report_name,
+                                       report_number, job_date);
+        }
+        else
+        {
+            PWARN("No GNC_PREF_FILENAME_FMT!");
+            job_name = g_strdup_printf ("%s %s %s", report_name,
+                                         report_number, job_date);
+        }
         g_free(format);
     }
     g_free (report_name);
