@@ -78,12 +78,12 @@ gnc_print_unstable_message(void)
 {
     if (!is_development_version) return;
 
-    std::cerr << bl::translate ("This is a development version. It may or may not work.") << "\n"
-              << bl::translate ("Report bugs and other problems to gnucash-devel@gnucash.org") << "\n"
+    std::cerr << _("This is a development version. It may or may not work.") << "\n"
+              << _("Report bugs and other problems to gnucash-devel@gnucash.org") << "\n"
               /* Translators: {1} will be replaced with an URL*/
-              << bl::format (bl::translate ("You can also lookup and file bug reports at {1}")) % PACKAGE_BUGREPORT << "\n"
+              << bl::format (std::string{_("You can also lookup and file bug reports at {1}")}) % PACKAGE_BUGREPORT << "\n"
               /* Translators: {1} will be replaced with an URL*/
-              << bl::format (bl::translate ("To find the last stable version, please refer to {1}")) % PACKAGE_URL << "\n";
+              << bl::format (std::string{_("To find the last stable version, please refer to {1}")}) % PACKAGE_URL << "\n";
 }
 
 static void
@@ -100,8 +100,8 @@ Gnucash::gnc_load_scm_config (void)
     if (!is_system_config_loaded)
     {
         /* Translators: Guile is the programming language of the reports */
-        auto msg = bl::translate ("Loading system wide Guile extensions…").str (gnc_get_boost_locale());
-        update_message (msg.c_str());
+        auto msg = _("Loading system wide Guile extensions…");
+        update_message (msg);
         auto system_config_dir = gnc_path_get_pkgsysconfdir ();
         auto system_config = g_build_filename (system_config_dir, "config", nullptr);
         is_system_config_loaded = gfec_try_load (system_config);
@@ -112,8 +112,8 @@ Gnucash::gnc_load_scm_config (void)
     static auto is_user_config_loaded = false;
     if (!is_user_config_loaded)
     {
-        auto msg = bl::translate ("Loading user specific Guile extensions…").str (gnc_get_boost_locale());
-        update_message (msg.c_str());
+        auto msg = _("Loading user specific Guile extensions…");
+        update_message (msg);
         auto config_filename = g_build_filename (gnc_userconfig_dir (), "config-user.scm", nullptr);
         is_user_config_loaded = gfec_try_load (config_filename);
         g_free (config_filename);
@@ -210,6 +210,7 @@ Gnucash::CoreApp::CoreApp ()
 
     gnc_init_boost_locale (localedir);
     std::cerr.imbue (gnc_get_boost_locale());
+    std::cout.imbue (gnc_get_boost_locale());
     g_free(localedir);
 }
 
@@ -221,9 +222,9 @@ Gnucash::CoreApp::CoreApp (const char* app_name)
     m_app_name = std::string(app_name);
 
     // Now that gettext is properly initialized, set our help tagline.
-    m_tagline = bl::translate("- GnuCash, accounting for personal and small business finance").str(gnc_get_boost_locale());
+    m_tagline = _("- GnuCash, accounting for personal and small business finance");
     m_opt_desc_display = std::make_unique<bpo::options_description>
-        ((bl::format (bl::gettext ("{1} [options] [datafile]")) % m_app_name).str() + std::string(" ") + m_tagline);
+        ((bl::format (std::string{_("{1} [options] [datafile]")}) % m_app_name).str() + std::string(" ") + m_tagline);
     add_common_program_options();
 }
 
@@ -267,15 +268,15 @@ Gnucash::CoreApp::parse_command_line (int argc, char **argv)
 
     if (m_show_version)
     {
-        bl::format rel_fmt (bl::translate ("GnuCash {1}"));
-        bl::format dev_fmt (bl::translate ("GnuCash {1} development version"));
+        bl::format rel_fmt (std::string{_("GnuCash {1}")});
+        bl::format dev_fmt (std::string{_("GnuCash {1} development version")});
 
         if (is_development_version)
             std::cout << dev_fmt % gnc_version () << "\n";
         else
             std::cout << rel_fmt % gnc_version () << "\n";
 
-        std::cout << bl::translate ("Build ID") << ": " << gnc_build_id () << "\n";
+        std::cout << _("Build ID") << ": " << gnc_build_id () << "\n";
         exit(0);
     }
 
