@@ -170,8 +170,8 @@ scm_run_gnucash (void *data, [[maybe_unused]] int argc, [[maybe_unused]] char **
     gnc_hook_add_dangler(HOOK_UI_SHUTDOWN, (GFunc)gnc_file_quit, NULL, NULL);
 
     /* Install Price Quote Sources */
-    auto msg = bl::translate ("Checking Finance::Quote...").str(gnc_get_boost_locale());
-    gnc_update_splash_screen (msg.c_str(), GNC_SPLASH_PERCENTAGE_UNKNOWN);
+    auto msg = _("Checking Finance::Quote...");
+    gnc_update_splash_screen (msg, GNC_SPLASH_PERCENTAGE_UNKNOWN);
     scm_c_use_module("gnucash price-quotes");
     scm_c_eval_string("(gnc:price-quotes-install-sources)");
 
@@ -179,8 +179,8 @@ scm_run_gnucash (void *data, [[maybe_unused]] int argc, [[maybe_unused]] char **
 
     if (!user_file_spec->nofile && (fn = get_file_to_load (user_file_spec->file_to_load)) && *fn )
     {
-        auto msg = bl::translate ("Loading data...").str(gnc_get_boost_locale());
-        gnc_update_splash_screen (msg.c_str(), GNC_SPLASH_PERCENTAGE_UNKNOWN);
+        auto msg = _("Loading data...");
+        gnc_update_splash_screen (msg, GNC_SPLASH_PERCENTAGE_UNKNOWN);
         gnc_file_open_file(gnc_get_splash_screen(), fn, /*open_readonly*/ FALSE);
         g_free(fn);
     }
@@ -272,7 +272,10 @@ Gnucash::Gnucash::configure_program_options (void)
     auto context = g_option_context_new (m_tagline.c_str());
     auto gtk_options = gtk_get_option_group(FALSE);
     g_option_context_add_group (context, gtk_options);
-    m_gtk_help_msg = g_option_context_get_help (context, FALSE, gtk_options);
+
+    auto help_cstr = g_option_context_get_help (context, FALSE, gtk_options);
+    m_gtk_help_msg = help_cstr;
+    g_free (help_cstr);
     g_option_context_free (context);
 
     bpo::options_description app_options(_("Application Options"));
@@ -306,11 +309,11 @@ Gnucash::Gnucash::start ([[maybe_unused]] int argc, [[maybe_unused]] char **argv
     // Will be removed in 5.0
     if (m_add_quotes)
     {
-        std::cerr << bl::translate ("The '--add-price-quotes' option to gnucash has been deprecated and will be removed in GnuCash 5.0. "
-                                    "Please use 'gnucash-cli --quotes get <datafile>' instead.") << "\n";
+        std::cerr << _("The '--add-price-quotes' option to gnucash has been deprecated and will be removed in GnuCash 5.0. "
+                       "Please use 'gnucash-cli --quotes get <datafile>' instead.") << "\n";
         if (!m_file_to_load || m_file_to_load->empty())
         {
-            std::cerr << bl::translate("Missing data file parameter") << "\n\n"
+            std::cerr << _("Missing data file parameter") << "\n\n"
             << *m_opt_desc_display.get();
             return 1;
         }
@@ -342,10 +345,10 @@ main(int argc, char ** argv)
     /* We need to initialize gtk before looking up all modules */
     if(!gtk_init_check (&argc, &argv))
     {
-        std::cerr << bl::format (bl::translate ("Run '{1} --help' to see a full list of available command line options.")) % *argv[0]
+        std::cerr << bl::format (std::string{("Run '{1} --help' to see a full list of available command line options.")}) % *argv[0]
         << "\n"
         // Translators: Do not translate $DISPLAY! It is an environment variable for X11
-        << bl::translate ("Error: could not initialize graphical user interface and option add-price-quotes was not set.\n"
+        << _("Error: could not initialize graphical user interface and option add-price-quotes was not set.\n"
         "Perhaps you need to set the $DISPLAY environment variable?");
         return 1;
     }
