@@ -702,7 +702,10 @@ CsvImpTransAssist::check_for_valid_filename ()
 {
     auto file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(file_chooser));
     if (!file_name || g_file_test (file_name, G_FILE_TEST_IS_DIR))
+    {
+        g_free (file_name);
         return false;
+    }
 
     auto filepath = gnc_uri_get_path (file_name);
     auto starting_dir = g_path_get_dirname (filepath);
@@ -1572,9 +1575,7 @@ void CsvImpTransAssist::preview_refresh_table ()
 
     /* Start with counting the current number of columns (ntcols)
      * we have in the treeview */
-    auto columns = gtk_tree_view_get_columns (treeview);
-    auto ntcols = g_list_length(columns);
-    g_list_free (columns);
+    auto ntcols = gtk_tree_view_get_n_columns (treeview);
 
     /* Drop redundant columns if the model has less data columns than the new model
      * ntcols = n° of columns in treeview (1 error column + x data columns)
@@ -2121,7 +2122,7 @@ CsvImpTransAssist::assist_summary_page_prepare ()
     try
     {
     /* Translators: {1} will be replaced with a filename */
-      text += (bl::format (bl::translate ("The transactions were imported from file '{1}'.")) % m_file_name).str(gnc_get_boost_locale());
+        text += (bl::format (std::string{_("The transactions were imported from file '{1}'.")}) % m_file_name).str();
         text += "</b></span>";
     }
     catch (const bl::conv::conversion_error& err)
