@@ -68,11 +68,6 @@ void gnc_customer_import_gui_option4_cb (GtkWidget *widget, gpointer data);
 void gnc_customer_import_gui_option5_cb (GtkWidget *widget, gpointer data);
 void gnc_customer_import_gui_type_cb (GtkWidget *widget, gpointer data);
 
-// utils
-static gchar *gnc_input_dialog (GtkWidget *parent, const gchar *title, const gchar *msg, const gchar *default_input);
-static void gnc_info2_dialog (GtkWidget *parent, const gchar *title, const gchar *msg);
-
-
 CustomerImportGui *
 gnc_plugin_customer_import_showGUI(GtkWindow *parent)
 {
@@ -353,115 +348,3 @@ void gnc_customer_import_gui_type_cb (GtkWidget *widget, gpointer data)
     //printf ("TYPE set to, %s\n",gui->type); // DEBUG
 
 }
-
-
-
-/********************************************************************\
- * gnc_input_dialog                                                 *
- *   simple convenience dialog to get a single value from the user  *
- *   user may choose between "Ok" and "Cancel"                      *
- *                                                                  *
- * NOTE: This function does not return until the dialog is closed   *
- *                                                                  *
- * Args:   parent  - the parent window or NULL                      *
- *         title   - the title of the dialog                        *
- *         msg     - the message to display                         *
- *         default_input - will be displayed as default input       *
- * Return: the input (text) the user entered, if pressed "Ok"       *
- *         NULL, if pressed "Cancel"                                *
-\********************************************************************/
-static gchar *
-gnc_input_dialog (GtkWidget *parent, const gchar *title, const gchar *msg, const gchar *default_input)
-{
-    GtkWidget *dialog, *label, *content_area;
-    gint result;
-    GtkWidget *view;
-    GtkTextBuffer *buffer;
-    gchar *user_input;
-    GtkTextIter start, end;
-
-    /* Create the widgets */
-    dialog = gtk_dialog_new_with_buttons (title, GTK_WINDOW (parent),
-                                          GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                          _("_OK"), GTK_RESPONSE_ACCEPT,
-                                          _("_Cancel"), GTK_RESPONSE_REJECT,
-                                          NULL);
-    content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-
-    // add a label
-    label = gtk_label_new (msg);
-    gtk_box_pack_start(GTK_BOX(content_area), label, FALSE, FALSE, 0);
-
-    // add a textview
-    view = gtk_text_view_new ();
-    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (view), GTK_WRAP_WORD_CHAR);
-    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-    gtk_text_buffer_set_text (buffer, default_input, -1);
-    gtk_box_pack_start(GTK_BOX(content_area), view, TRUE, TRUE, 0);
-    
-    // run the dialog
-    gtk_widget_show_all (dialog);
-    result = gtk_dialog_run (GTK_DIALOG (dialog));
-
-    if (result == GTK_RESPONSE_REJECT)
-        user_input = 0;
-    else
-    {
-        gtk_text_buffer_get_start_iter (buffer, &start);
-        gtk_text_buffer_get_end_iter (buffer, &end);
-        user_input = gtk_text_buffer_get_text (buffer,
-                                               &start, &end, FALSE);
-    }
-
-    gtk_widget_destroy (dialog);
-
-    return user_input;
-}
-
-/********************************************************************\
- * gnc_info2_dialog                                                 *
- *   displays an information dialog box (with scrollable text area) *
- *                                                                  *
- * NOTE: This function does not return until the dialog is closed   *
- *                                                                  *
- * Args:   parent  - the parent window or NULL                      *
- *         title   - the title of the dialog                        *
- *         msg     - the message to display                         *
- * Return: none                                                     *
-\********************************************************************/
-static void
-gnc_info2_dialog (GtkWidget *parent, const gchar *title, const gchar *msg)
-{
-    GtkWidget *dialog, *scrolledwindow, *content_area;
-    GtkWidget *view;
-    GtkTextBuffer *buffer;
-    gint width, height;
-
-    /* Create the widgets */
-    dialog = gtk_dialog_new_with_buttons (title, GTK_WINDOW (parent),
-                                          GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                          _("_OK"), GTK_RESPONSE_ACCEPT,
-                                          NULL);
-    content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
-
-    // add a scroll area
-    scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
-    gtk_box_pack_start(GTK_BOX(content_area), scrolledwindow, TRUE, TRUE, 0);
-
-    // add a textview
-    view = gtk_text_view_new ();
-    gtk_text_view_set_editable (GTK_TEXT_VIEW (view), FALSE);
-    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-    gtk_text_buffer_set_text (buffer, msg, -1);
-    gtk_container_add (GTK_CONTAINER (scrolledwindow), view);
-
-    // run the dialog
-    if (parent)
-    {
-        gtk_window_get_size (GTK_WINDOW(parent), &width, &height);
-        gtk_window_set_default_size (GTK_WINDOW(dialog), width, height);
-    }
-    gtk_widget_show_all (dialog);
-    gtk_dialog_run (GTK_DIALOG (dialog));
-    gtk_widget_destroy (dialog);
-}
