@@ -121,7 +121,7 @@ static void
 gnc_plugin_customer_import_cmd_test (GtkAction *action, GncMainWindowActionData *data)
 {
     ENTER ("action %p, main window data %p", action, data);
-    g_message ("customer_import");
+    PINFO ("customer_import");
 
     gnc_plugin_customer_import_showGUI (GTK_WINDOW(data->window));
 
