@@ -1093,7 +1093,7 @@ static inline void
 maybe_add_string (GNCImportMainMatcher *info, GHashTable *hash, const char *str)
 {
     char *new_string;
-    if (!str || !str[0] || g_hash_table_lookup (info->desc_hash, str))
+    if (!str || !str[0] || g_hash_table_lookup (hash, str))
         return;
     new_string = g_strdup (str);
     info->new_strings = g_list_prepend (info->new_strings, new_string);
@@ -2189,21 +2189,6 @@ refresh_model_row (GNCImportMainMatcher *gui,
     gtk_tree_selection_unselect_all (selection);
 }
 
-void
-gnc_gen_trans_list_add_trans (GNCImportMainMatcher *gui, Transaction *trans)
-{
-    Account* acc = NULL;
-    Split* split = NULL;
-    int i=0;
-
-    split = xaccTransGetSplit (trans, 0);
-    acc = xaccSplitGetAccount (split);
-    defer_bal_computation (gui, acc);
-
-    gnc_gen_trans_list_add_trans_with_ref_id (gui, trans, 0);
-    return;
-}/* end gnc_import_add_trans() */
-
 void
 gnc_gen_trans_list_show_reconcile_after_close_button (GNCImportMainMatcher *info,
                                                       gboolean reconcile_after_close,
@@ -2219,6 +2204,22 @@ gnc_gen_trans_list_get_reconcile_after_close_button (GNCImportMainMatcher *info)
     return info->reconcile_after_close;
 }
 
+
+void
+gnc_gen_trans_list_add_trans (GNCImportMainMatcher *gui, Transaction *trans)
+{
+    Account* acc = NULL;
+    Split* split = NULL;
+    int i=0;
+
+    split = xaccTransGetSplit (trans, 0);
+    acc = xaccSplitGetAccount (split);
+    defer_bal_computation (gui, acc);
+
+    gnc_gen_trans_list_add_trans_with_ref_id (gui, trans, 0);
+    return;
+}/* end gnc_import_add_trans() */
+
 void
 gnc_gen_trans_list_add_trans_with_ref_id (GNCImportMainMatcher *gui, Transaction *trans, guint32 ref_id)
 {
