@@ -45,7 +45,7 @@
     Accounts.
 	@{
 */
-const gchar * gnc_import_get_acc_online_id(Account * account);
+gchar * gnc_import_get_acc_online_id(Account * account);
 void gnc_import_set_acc_online_id(Account * account,
                                   const gchar * string_value);
 /** @} */
@@ -54,7 +54,7 @@ void gnc_import_set_acc_online_id(Account * account,
     Transactions.
 	@{
 */
-const gchar * gnc_import_get_trans_online_id(Transaction * transaction);
+gchar * gnc_import_get_trans_online_id(Transaction * transaction);
 void gnc_import_set_trans_online_id(Transaction * transaction,
                                     const gchar * string_value);
 /** @} */
@@ -66,7 +66,7 @@ gboolean gnc_import_trans_has_online_id(Transaction * transaction);
     Splits.
 	@{
 */
-const gchar * gnc_import_get_split_online_id(Split * split);
+gchar * gnc_import_get_split_online_id(Split * split);
 void gnc_import_set_split_online_id(Split * split,
                                     const gchar * string_value);
 /** @} */
