@@ -270,7 +270,7 @@
            (default-currency
              (gnc-commodity-table-find-full
               (gnc-commodity-table-get-table (gnc-get-current-book))
-              GNC_COMMODITY_NS_CURRENCY default-currency-name))
+              (GNC-COMMODITY-NS-CURRENCY) default-currency-name))
            (sorted-accounts-list '())
            (markable-xtns '())
            (sorted-qif-files-list (sort qif-files-list
@@ -444,7 +444,8 @@
                                                  progress-dialog)
 
                   ;; rebalance and commit everything
-                  (xaccTransCommitEdit gnc-xtn))))
+                  (xaccTransCommitEdit gnc-xtn)
+                  (xaccTransRecordPrice gnc-xtn PRICE-SOURCE-SPLIT-IMPORT))))
           (qif-file:xtns qif-file)))
        sorted-qif-files-list)
 
