@@ -73,7 +73,7 @@ static void
 update_message(const gchar *msg)
 {
     //gnc_update_splash_screen(msg, GNC_SPLASH_PERCENTAGE_UNKNOWN);
-    g_message("%s", msg);
+    PINFO("%s", msg);
 }
 
 static void
@@ -336,9 +336,13 @@ gnc_get_default_report_font_family(void)
 
     pango_font_description_free (font_desc);
 
-    if (default_font_family == NULL ||
-        g_str_has_prefix (default_font_family, ".AppleSystemUIFont"))
-        return g_strdup("Arial");
+    if (!default_font_family)
+        return g_strdup ("Arial");
+    else if (g_str_has_prefix (default_font_family, ".AppleSystemUIFont"))
+    {
+        g_free (default_font_family);
+        return g_strdup ("Arial");
+    }
     else
         return default_font_family;
 }
