@@ -37,11 +37,12 @@
 (use-modules (gnucash reports standard new-aging))
 (use-modules (gnucash reports standard new-owner-report))
 
+(export gnc:budget-report-create)
 (export gnc:register-report-create)
 (export gnc:invoice-report-create)
 (export gnc:payables-report-create)
 (export gnc:receivables-report-create)
-(export gnc:owner-report-create)
+(export gnc:owner-report-create)        ;deprecate
 (export gnc:owner-report-create-with-enddate)
 
 (let ((loc-spec (if (string-prefix? "de_DE" (gnc-locale-name)) 'de_DE 'us)))
@@ -78,7 +79,16 @@
         0
         ))
 
+(define budget-ID "810ed4b25ef0486ea43bbd3dddb32b11")
+(define (gnc:budget-report-create budget)
+  (if (gnc:find-report-template budget-ID)
+      (let* ((options (gnc:make-report-options budget-ID))
+             (bgt-op (gnc:lookup-option options gnc:pagename-general "Budget")))
+        (gnc:option-set-value bgt-op budget)
+        (gnc:make-report budget-ID options))
+      -1))
+
 (define gnc:payables-report-create payables-report-create-internal)
 (define gnc:receivables-report-create receivables-report-create-internal)
-(define gnc:owner-report-create owner-report-create)
+(define gnc:owner-report-create owner-report-create) ;deprecated
 (define gnc:owner-report-create-with-enddate owner-report-create-with-enddate)
