@@ -70,7 +70,7 @@ accounts may be tagged with *EUGOODS* in the account description."))
    (gnc:html-markup-p
     (G_ "This message will be removed when tax accounts are specified."))))
 
-(define* (gst-statement-renderer rpt #:optional export-type file-name)
+(define* (gst-statement-renderer rpt #:optional export-type)
   (define (opt-val section name)
     (gnc:option-value
      (gnc:lookup-option (gnc:report-options rpt) section name)))
@@ -83,10 +83,6 @@ accounts may be tagged with *EUGOODS* in the account description."))
      #:custom-source-accounts sales-purch-accounts
      #:custom-split-filter gst-custom-split-filter
      #:export-type export-type))
-  (when file-name
-    (issue-deprecation-warning "gst-statement-renderer filename is \
-obsolete, and not supported for exports. please set html-document \
-export-string instead. this warning will be removed in GnuCash 5.0"))
   (when (null? (opt-val "Accounts" "Tax Accounts"))
     (gnc:html-document-add-object! document TAX-SETUP-DESC))
   document)
@@ -158,21 +154,24 @@ for taxes paid on expenses, and type LIABILITY for taxes collected on sales.")
   (gnc:register-option
    options
    (gnc:make-multichoice-callback-option
-    pagename-format (N_ "Report format")
-    "a" (G_ "Report Format") 'default
-    (list (vector 'default
-                  (G_ "Default Format")
-                  (G_ "Default Format"))
-          (vector 'au-bas
-                  (G_ "Australia BAS")
-                  (G_ "Australia Business Activity Statement. Specify sales, \
-purchase and tax accounts."))
-          (vector 'uk-vat
-                  (G_ "UK VAT Return")
-                  (G_ "UK VAT Return. Specify sales, purchase and tax \
+    pagename-format (N_ "Report Format")
+    "a"
+    (string-join
+     (list
+      (G_ "Report Format")
+      (G_ "Default Format")
+      (G_ "Australia Business Activity Statement. Specify sales, \
+purchase and tax accounts.")
+      (G_ "UK VAT Return. Specify sales, purchase and tax \
 accounts. EU rules may be used. Denote EU VAT accounts *EUVAT* in \
 account description, and denote EU goods sales and purchases accounts \
-with *EUGOODS* in the account description."))) #f
+with *EUGOODS* in the account description."))
+     "\n* ")
+    'default
+    (list (vector 'default (G_ "Default Format"))
+          (vector 'au-bas (G_ "Australia BAS"))
+          (vector 'uk-vat (G_ "UK VAT Return")))
+     #f
     (lambda (x)
       (for-each
        (match-lambda
@@ -201,8 +200,8 @@ with *EUGOODS* in the account description."))) #f
   ;; multiple currencies in a government report. Plus, single currency
   ;; means only 1 amount per heading for CSV output.
   (gnc:option-set-default-value
-   (gnc:lookup-option options gnc:pagename-general "Common Currency") #t)
-  (gnc:option-make-internal! options gnc:pagename-general "Common Currency")
+   (gnc:lookup-option options "Currency" "Common Currency") #t)
+  (gnc:option-make-internal! options "Currency" "Common Currency")
 
   ;; Set default dates to report on last quarter.
   (gnc:option-set-default-value
@@ -228,9 +227,6 @@ with *EUGOODS* in the account description."))) #f
   (gnc:option-set-default-value
    (gnc:lookup-option options pagename-sorting "Secondary Key")
    'none)
-  (gnc:option-set-default-value
-   (gnc:lookup-option options pagename-sorting "Secondary Subtotal")
-   'none)
 
   ;; Disable display options not being used anymore
   (gnc:option-make-internal! options gnc:pagename-display "Shares")
@@ -263,7 +259,7 @@ with *EUGOODS* in the account description."))) #f
          (accounts-tax-paid      (accfilter tax-accounts ACCT-TYPE-ASSET))
          (accounts-sales         (opt-val gnc:pagename-accounts "Sales"))
          (accounts-purchases     (opt-val gnc:pagename-accounts "Purchases"))
-         (common-currency        (opt-val gnc:pagename-general "Report's currency")))
+         (common-currency        (opt-val "Currency" "Report's currency")))
 
     (define (split-adder split accountlist)
       (define txn (xaccSplitGetParent split))
@@ -299,7 +295,7 @@ with *EUGOODS* in the account description."))) #f
     ;;         start-dual-column?   - unused in GST report
     ;;         friendly-heading-fn  - unused in GST report
 
-    (case (opt-val pagename-format "Report format")
+    (case (opt-val pagename-format "Report Format")
       ((default)
        (let* ((net-sales (lambda (s) (myneg (split-adder s accounts-sales))))
               (tax-sales (lambda (s) (myneg (split-adder s accounts-tax-collected))))
@@ -405,15 +401,15 @@ with *EUGOODS* in the account description."))) #f
               (box-8 (lambda (s) (myneg (split-adder s eu-sales-accts))))
               (box-9 (lambda (s) (split-adder s eu-purch-accts))))
          (list
-          (vector "Box 1 VAT Sales"          box-1 #f #t #f #f)
-          (vector "Box 2 VAT Reverse EU"     box-2 #f #t #f #f)
-          (vector "Box 3 VAT Output"         box-3 #f #t #f #f)
-          (vector "Box 4 VAT Purchases"      box-4 #f #t #f #f)
-          (vector "Box 5 VAT Difference"     box-5 #f #t #f #f)
-          (vector "Box 6 Tot Sales"          box-6 #f #t #f #f)
-          (vector "Box 7 Tot Purchases"      box-7 #f #t #f #f)
-          (vector "Box 8 EU Goods Sales"     box-8 #f #t #f #f)
-          (vector "Box 9 EU Goods Purchases" box-9 #f #t #f #f)))))))
+          (vector "Box 1 VAT Sales"                         box-1 #f #t #f #f)
+          (vector "Box 2 VAT Goods Purchases from EU to NI" box-2 #f #t #f #f)
+          (vector "Box 3 VAT Output"                        box-3 #f #t #f #f)
+          (vector "Box 4 VAT Purchases"                     box-4 #f #t #f #f)
+          (vector "Box 5 VAT Difference"                    box-5 #f #t #f #f)
+          (vector "Box 6 Tot Sales"                         box-6 #f #t #f #f)
+          (vector "Box 7 Tot Purchases"                     box-7 #f #t #f #f)
+          (vector "Box 8 Net Goods Sales from NI to EU"     box-8 #f #t #f #f)
+          (vector "Box 9 Net Goods Purchases from EU to NI" box-9 #f #t #f #f)))))))
 
 ;; Define the report.
 (gnc:define-report
