@@ -276,7 +276,7 @@
           '("03/18/20" "Sell SPY" "-75 SPY" "75 SPY" "Sell" "CAD" "C$1.0000"
             "C$12,000.00" "C$9.95" "C$12,000.00" "C$9.95" "C$18,009.95"
             "C$240.13" "C$18,009.95" "C$11,990.05" "-C$6,019.90"
-            "-C$6,009.95" "-C$6,009.95" "-C$6,019.90" "-C$6,019.90")
+            "-C$6,009.95" "-C$6,009.95" "-C$6,009.95" "-C$6,019.90" "-C$6,019.90")
           (sxml->table-row-col sxml 1 3 #f))
 
         (test-equal "BUY 250 SPY"
@@ -307,7 +307,7 @@
           '("05/21/20" "Sell SPY" "-135 SPY" "765 SPY" "Sell" "CAD" "C$1.0000"
             "C$21,500.00" "C$9.95" "C$21,500.00" "C$9.95" "C$89,266.92"
             "C$116.69" "C$15,752.98" "C$21,490.05" "C$5,737.06"
-            "C$5,747.02" "-C$262.94" "-C$282.84" "-C$282.84")
+            "C$5,747.02" "C$5,747.02" "-C$262.94" "-C$282.84" "-C$282.84")
           (sxml->table-row-col sxml 1 8 #f))
 
         (test-equal "BUY 150 SPY"
@@ -317,10 +317,10 @@
           (sxml->table-row-col sxml 1 9 #f))
 
         (test-equal "sell 915 SPY close long"
-          ' ("06/10/20" "Sell SPY" "-915 SPY" "0 SPY" "Sell" "CAD"
-             "C$1.0000" "C$128,100.00" "C$9.95" "C$128,100.00" "C$9.95"
-             "C$0.00" "C$120.51" "C$110,266.92" "C$128,090.05" "C$17,823.14"
-             "C$17,833.08" "C$17,570.15" "C$17,540.30" "C$17,540.30")
+          '("06/10/20" "Sell SPY" "-915 SPY" "0 SPY" "Sell" "CAD"
+            "C$1.0000" "C$128,100.00" "C$9.95" "C$128,100.00" "C$9.95"
+            "C$0.00" "C$120.51" "C$110,266.92" "C$128,090.05" "C$17,823.14"
+            "C$17,833.08" "C$17,833.08" "C$17,570.15" "C$17,540.30" "C$17,540.30")
           (sxml->table-row-col sxml 1 10 #f))
 
         (test-equal "short-sell 85 SPY"
@@ -339,14 +339,14 @@
           '("06/18/20" "Buy SPY Close Short" "50 SPY" "-100 SPY" "Cover Buy"
             "CAD" "C$1.0000" "-C$5,000.00" "C$9.95" "-C$5,000.00" "C$9.95"
             "-C$15,286.73" "C$152.87" "-C$7,643.37" "-C$5,009.95" "C$2,633.42"
-            "C$2,643.37" "C$20,213.52" "C$20,173.72" "C$20,173.72")
+            "C$2,643.37" "C$2,643.37" "C$20,213.52" "C$20,173.72" "C$20,173.72")
           (sxml->table-row-col sxml 1 13 #f))
 
         (test-equal "BUY 100 SPY close short"
           '("06/20/20" "Buy SPY Close Short" "100 SPY" "0 SPY" "Cover Buy"
             "CAD" "C$1.0000" "-C$8,000.00" "C$4.98" "-C$8,000.00" "C$4.98"
             "C$0.00" "C$152.87" "-C$15,286.73" "-C$8,004.98" "C$7,281.75"
-            "C$7,286.73" "C$27,500.25" "C$27,455.47" "C$27,455.47")
+            "C$7,286.73" "C$7,286.73" "C$27,500.25" "C$27,455.47" "C$27,455.47")
           (sxml->table-row-col sxml 1 14 #f))
 
         (test-equal "BUY 100 SPY"
