@@ -435,7 +435,7 @@ the option '~a'."))
     (if (string? currency)
         (gnc-commodity-table-lookup
          (gnc-commodity-table-get-table (gnc-get-current-book))
-         GNC_COMMODITY_NS_CURRENCY currency)
+         (GNC-COMMODITY-NS-CURRENCY) currency)
         currency))
 
    (let* ((value (currency->scm default-value))
@@ -466,9 +466,14 @@ the option '~a'."))
          sort-tag
          documentation-string)
 
+  (define (convert-to-guid item)
+    (if (string? item) item (gncBudgetGetGUID item)))
+
+  (define (convert-to-budget item)
+    (if (string? item) (gnc-budget-lookup item (gnc-get-current-book)) item))
+
   (let* ((initial-budget (gnc-budget-get-default (gnc-get-current-book)))
-	 (selection-budget initial-budget)
-         )
+	 (selection-budget (convert-to-guid initial-budget)))
 
     (gnc:make-option
      section 
@@ -478,12 +483,12 @@ the option '~a'."))
      documentation-string
 
      ;; getter -- Return a budget pointer
-     (lambda () 
-       selection-budget)
+     (lambda ()
+       (convert-to-budget selection-budget))
 
      ;; setter -- takes a budget
      (lambda (x)
-       (set! selection-budget x))
+       (set! selection-budget (convert-to-guid x)))
 
      ;; default-getter
      ;; Default now is #f so saving is independent of book-level default
@@ -491,7 +496,7 @@ the option '~a'."))
        #f)
 
      ;; generate-restore-form
-     ;; "return 'ascii represention of a function'
+     ;; "return 'ascii representation of a function'
      ;; that will set the option passed as its lone parameter
      ;; to the value it was when the picker was first displayed"
      ;;
@@ -503,21 +508,20 @@ the option '~a'."))
 	"(lambda (option) "
 	"(if option ((gnc:option-setter option) "
 	"(gnc-budget-lookup "
-	(gnc:value->string (gncBudgetGetGUID selection-budget))
+	(gnc:value->string selection-budget)
 	" (gnc-get-current-book)))))"))
 
      ;; scm->kvp -- commit the change
      ;; b -- book;  p -- key-path
      (lambda (b p) 
-       (qof-book-set-option 
-	b (gncBudgetGetGUID selection-budget) p))
+       (qof-book-set-option b selection-budget p))
 
      ;; kvp->scm -- get the stored value
      (lambda (b p)
        (let ((v (qof-book-get-option b p)))
          (if (and v (string? v))
-	     (begin 
-	       (set! selection-budget (gnc-budget-lookup v (gnc-get-current-book)))))))
+	     (set! selection-budget (convert-to-guid
+                                     (gnc-budget-lookup v (gnc-get-current-book)))))))
 
      ;; value-validator -- returns (#t value) or (#f "failure message")
      ;; As no user-generated input, this legacy hard-wire is probably ok
@@ -557,7 +561,7 @@ the option '~a'."))
   (define (commodity->scm commodity)
     (if (string? commodity)
         (list 'commodity-scm
-              GNC_COMMODITY_NS_CURRENCY
+              (GNC-COMMODITY-NS-CURRENCY)
               commodity)
         (list 'commodity-scm
               (gnc-commodity-get-namespace commodity)
@@ -1556,7 +1560,7 @@ the option '~a'."))
     (if (string? currency-string)
         (gnc-commodity-table-lookup
          (gnc-commodity-table-get-table (gnc-get-current-book))
-         GNC_COMMODITY_NS_CURRENCY currency-string)
+         (GNC-COMMODITY-NS-CURRENCY) currency-string)
         #f))
 
   (define (currency? val)
