@@ -127,7 +127,7 @@ concatenate_child_result_chars (GSList* data_from_children)
         else
         {
             char* temp;
-            temp = g_strconcat (name, (gchar*) cr->data, NULL);
+            temp = g_strconcat (name, (gchar*) cr->data, nullptr);
             g_free (name);
             name = temp;
         }
