@@ -17,13 +17,13 @@
  * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  *                                                                  *
 \********************************************************************/
+#include <glib.h>
+#include <glib/gstdio.h>
+
 extern "C"
 {
 #include <config.h>
 
-#include <glib.h>
-#include <glib/gstdio.h>
-#include <stdlib.h>
 #include <unistd.h>
 
 #include "qof.h"
@@ -32,6 +32,8 @@ extern "C"
 #include "Account.h"
 }
 
+#include <cstdlib>
+
 #include "gnc-xml-helper.h"
 #include "gnc-xml.h"
 #include "sixtp-parsers.h"
