@@ -1334,6 +1334,12 @@ gnc_tm_get_today_start (struct tm *tm)
     gnc_tm_get_day_start(tm, time(NULL));
 }
 
+void
+gnc_tm_get_today_neutral (struct tm *tm)
+{
+    gnc_tm_get_day_neutral(tm, time(NULL));
+}
+
 void
 gnc_tm_get_today_end (struct tm *tm)
 {
