@@ -123,8 +123,8 @@ GncNumeric::GncNumeric(const std::string& str, bool autoround)
     static const std::string hex_frag("(0x[a-f0-9]+)");
     static const std::string slash( "[ \\t]*/[ \\t]*");
     /* The llvm standard C++ library refused to recognize the - in the
-     * numer_frag patter with the default ECMAScript syntax so we use the awk
-     * syntax.
+     * numer_frag pattern with the default ECMAScript syntax so we use the
+     * awk syntax.
      */
     static const regex numeral(numer_frag);
     static const regex hex(hex_frag);
@@ -1090,7 +1090,7 @@ gnc_numeric_to_decimal(gnc_numeric *a, guint8 *max_decimal_places)
     }
     catch (const std::exception& err)
     {
-        PWARN("%s", err.what());
+        PINFO ("%s", err.what());
         return FALSE;
     }
 }
