@@ -61,6 +61,8 @@ extern "C"
 // For GNC_ID_ROOT_ACCOUNT:
 #include "AccountP.h"
 
+#include "qofbook.hpp"
+
 static QofLogModule log_module = QOF_MOD_ENGINE;
 #define AB_KEY "hbci"
 #define AB_TEMPLATES "template-list"
@@ -1226,6 +1228,8 @@ qof_book_get_features (QofBook *book)
     GHashTable *features = g_hash_table_new_full (g_str_hash, g_str_equal,
                                                   NULL, g_free);
 
+    PWARN ("qof_book_get_features is now deprecated.");
+
     auto slot = frame->get_slot({GNC_FEATURES});
     if (slot != nullptr)
     {
@@ -1255,6 +1259,48 @@ qof_book_set_feature (QofBook *book, const gchar *key, const gchar *descr)
     }
 }
 
+std::vector<std::string>
+qof_book_get_unknown_features (QofBook *book, const FeaturesTable& features)
+{
+    std::vector<std::string> rv;
+    auto test_feature = [&](const KvpFrameImpl::map_type::value_type& feature)
+    {
+        if (features.find (feature.first) == features.end ())
+            rv.push_back (feature.second->get<const char*>());
+    };
+    auto frame = qof_instance_get_slots (QOF_INSTANCE (book));
+    auto slot = frame->get_slot({GNC_FEATURES});
+    if (slot != nullptr)
+    {
+        frame = slot->get<KvpFrame*>();
+        std::for_each (frame->begin (), frame->end (), test_feature);
+    }
+    return rv;
+}
+
+bool
+qof_book_test_feature (QofBook *book, const char *feature)
+{
+    auto frame = qof_instance_get_slots (QOF_INSTANCE (book));
+    return (frame->get_slot({GNC_FEATURES, feature}) != nullptr);
+}
+
+void
+qof_book_unset_feature (QofBook *book, const gchar *key)
+{
+    KvpFrame *frame = qof_instance_get_slots (QOF_INSTANCE (book));
+    auto feature_slot = frame->get_slot({GNC_FEATURES, key});
+    if (!feature_slot)
+    {
+        PWARN ("no feature %s. bail out.", key);
+        return;
+    }
+    qof_book_begin_edit (book);
+    delete frame->set_path({GNC_FEATURES, key}, nullptr);
+    qof_instance_set_dirty (QOF_INSTANCE (book));
+    qof_book_commit_edit (book);
+}
+
 void
 qof_book_load_options (QofBook *book, GNCOptionLoad load_cb, GNCOptionDB *odb)
 {
