@@ -41,6 +41,7 @@
 #define QOF_BOOK_H
 
 #ifdef __cplusplus
+#include <glib.h> //To preempt it being included extern "C" in a later header.
 extern "C"
 {
 #endif
@@ -86,7 +87,7 @@ struct _QofBook
     /* Boolean indicates that the session is dirty -- that is, it has
      * not yet been written out to disk after the last time the
      * backend ran commit_edit(). This is distinct from the inherited
-     * QofInstance::dirty, which indicates that some persisitent
+     * QofInstance::dirty, which indicates that some persistent
      * property of the book object itself has been edited and not
      * committed. Some backends write data out as part of
      * commit_edit() and so don't use this flag.
@@ -210,7 +211,7 @@ void qof_book_destroy (QofBook *book);
 /** Close a book to editing.
 
 It is up to the application to check this flag,
-and once marked closed, books cannnot be marked as open.
+and once marked closed, books cannot be marked as open.
 */
 void qof_book_mark_closed (QofBook *book);
 
@@ -223,7 +224,7 @@ void qof_book_mark_closed (QofBook *book);
  *  type.
  *
  *  If the collection doesn't yet exist for the indicated type,
- *  it is created.  Thus, this routine is gaurenteed to return
+ *  it is created.  Thus, this routine is guaranteed to return
  *  a non-NULL value.  (Unless the system malloc failed (out of
  *  memory) in which case what happens??).
  */
@@ -381,6 +382,7 @@ void qof_book_option_frame_delete (QofBook *book, const char* opt_name);
 /** Access functions for reading and setting the used-features on this book.
  */
 GHashTable *qof_book_get_features (QofBook *book);
+void qof_book_unset_feature (QofBook *book, const gchar *key);
 void qof_book_set_feature (QofBook *book, const gchar *key, const gchar *descr);
 
 void qof_book_begin_edit(QofBook *book);
